pub struct LocalHealthObserverConfig {
pub ema_numerator: u32,
pub ema_denominator: u32,
pub queue_pressure_cap: u32,
pub rtt_hysteresis_ms: u32,
pub loss_hysteresis_bps: u32,
pub queue_pressure_hysteresis: u32,
pub min_smoothed_update_interval_ms: u64,
}Fields
ema_numerator: u32ema_denominator: u32queue_pressure_cap: u32rtt_hysteresis_ms: u32Small EMA deltas below these thresholds are suppressed to avoid thrash.
loss_hysteresis_bps: u32queue_pressure_hysteresis: u32min_smoothed_update_interval_ms: u64Minimum interval between noisy smoothed updates unless the change is large.
Implementations
Sourceimpl LocalHealthObserverConfig
impl LocalHealthObserverConfig
pub fn for_testing() -> Self