pub struct IndexedJournalHandler { /* private fields */ }Expand description
Production indexed journal handler
Provides efficient O(log n) lookups using B-tree indexes, O(1) membership testing using Bloom filters, and cryptographic verification or integrity using Merkle trees.
Performance Guarantees
facts_by_predicate: O(log n + k) where k is result sizefacts_by_authority: O(log n + k) where k is result sizefacts_in_range: O(log n + k) where k is result sizemight_contain: O(1) with <1% false positive ratemerkle_root: O(n) on first call, O(1) cachedverify_fact_inclusion: O(log n)
Concurrency Model
Uses parking_lot::RwLock for synchronous locking of the state bundle.
Each operation acquires and releases the lock in sub-millisecond time.
See module documentation for scale expectations and alternatives.
Implementations
Sourceimpl IndexedJournalHandler
impl IndexedJournalHandler
Sourcepub fn with_capacity(expected_elements: u64) -> Self
pub fn with_capacity(expected_elements: u64) -> Self
Create a new indexed journal handler with specified expected capacity